==> koffice-2.0.0.tar.bz2: koffice-2.0.0/plugins/artistictextshape/ArtisticTextShapeFactory.cpp <==
/* This file is part of the KDE project
 * Copyright (C) 2007 Jan Hambrecht <jaham@gmx.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "ArtisticTextShapeFactory.h"
#include "ArtisticTextShape.h"
#include "ArtisticTextShapeConfigWidget.h"

#include <KoXmlNS.h>
#include <KoColorBackground.h>

#include <klocale.h>

ArtisticTextShapeFactory::ArtisticTextShapeFactory(QObject *parent)
    : KoShapeFactory(parent, ArtisticTextShapeID, i18n("ArtisticTextShape"))
{
    setToolTip(i18n("A shape which shows a single text line"));
    setIcon( "text" );
    setLoadingPriority( 5 );
    setOdfElementNames( KoXmlNS::draw, QStringList( "custom-shape" ) );
}

KoShape *ArtisticTextShapeFactory::createDefaultShape() const
{
    ArtisticTextShape * text = new ArtisticTextShape();
    text->setBackground( new KoColorBackground( QColor( Qt::black) ) );
    return text;
}

KoShape *ArtisticTextShapeFactory::createShape(const KoProperties *) const
{
    return createDefaultShape();
}

QList<KoShapeConfigWidgetBase*> ArtisticTextShapeFactory::createShapeOptionPanels()
{
    QList<KoShapeConfigWidgetBase*> answer;
    answer.append( new ArtisticTextShapeConfigWidget() );
    return answer;
}

bool ArtisticTextShapeFactory::supports(const KoXmlElement & e) const
{
    return ( e.localName() == "custom-shape" && e.namespaceURI() == KoXmlNS::draw );
}

#include "ArtisticTextShapeFactory.moc"

==> koffice_2.2.2.orig.tar.bz2: koffice-2.2.2/plugins/artistictextshape/ArtisticTextShapeFactory.cpp <==
/* This file is part of the KDE project
 * Copyright (C) 2007 Jan Hambrecht <jaham@gmx.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "ArtisticTextShapeFactory.h"
#include "ArtisticTextShape.h"
#include "ArtisticTextShapeConfigWidget.h"

#include <KoXmlNS.h>
#include <KoColorBackground.h>

#include <klocale.h>

ArtisticTextShapeFactory::ArtisticTextShapeFactory(QObject *parent)
    : KoShapeFactoryBase(parent, ArtisticTextShapeID, i18n("ArtisticTextShape"))
{
    setToolTip(i18n("A shape which shows a single text line"));
    setIcon( "text" );
    setLoadingPriority( 5 );
    setOdfElementNames( KoXmlNS::draw, QStringList( "custom-shape" ) );
}

KoShape *ArtisticTextShapeFactory::createDefaultShape(KoResourceManager *) const
{
    ArtisticTextShape * text = new ArtisticTextShape();
    text->setBackground( new KoColorBackground( QColor( Qt::black) ) );
    return text;
}

bool ArtisticTextShapeFactory::supports(const KoXmlElement & e) const
{
    return ( e.localName() == "custom-shape" && e.namespaceURI() == KoXmlNS::draw );
}

#include <ArtisticTextShapeFactory.moc>
